;;; cus-load.el --- automatically extracted custom dependencies
;;
;;; Code:

(put 'mime-display 'custom-loads '(flow-fill mm-decode mm-view))
(put 'holidays 'custom-loads '(calendar))
(put 'SQL 'custom-loads '(sql))
(put 'spam-stat 'custom-loads '(spam-stat))
(put 'paren-showing-faces 'custom-loads '(paren))
(put 'refbib 'custom-loads '(refbib))
(put 'elp 'custom-loads '(elp))
(put 'org-table 'custom-loads '(org))
(put 'eshell-ext 'custom-loads '(esh-ext))
(put 'vhdl-template 'custom-loads '(vhdl-mode))
(put 'erc-query 'custom-loads '(erc))
(put 'shell 'custom-loads '(dirtrack shell terminal))
(put 'ffap 'custom-loads '(ffap))
(put 'locate 'custom-loads '(locate))
(put 'highlight-changes 'custom-loads '(hilit-chg))
(put 'nnmail 'custom-loads '(nnmail))
(put 'chistory 'custom-loads '(chistory))
(put 'shell-directories 'custom-loads '(shell))
(put 'idlwave-documentation 'custom-loads '(idlwave))
(put 'footnote 'custom-loads '(footnote))
(put 'pcomplete 'custom-loads '(em-cmpl pcmpl-cvs pcmpl-gnu pcmpl-linux pcmpl-rpm pcomplete))
(put 'gnus-fun 'custom-loads '(gnus-fun))
(put 'org-time 'custom-loads '(org))
(put 'calendar-tex 'custom-loads '(cal-tex))
(put 'savehist 'custom-loads '(savehist))
(put 'mail-hist 'custom-loads '(mail-hist))
(put 'gnus-article-emphasis 'custom-loads '(gnus-art))
(put 'dunnet 'custom-loads '(dunnet))
(put 'fortran 'custom-loads '(fortran))
(put 'eshell-script 'custom-loads '(em-script))
(put 'reftex-table-of-contents-browser 'custom-loads '(reftex-vars))
(put 'mspools 'custom-loads '(mspools))
(put 'gnus-article-headers 'custom-loads '(gnus-art gnus-sum gnus-fun))
(put 'f90 'custom-loads '(f90))
(put 'allout 'custom-loads '(allout))
(put 'mode-line 'custom-loads '(time))
(put 'ediff-hook 'custom-loads '(ediff-init ediff-mult))
(put 'woman-faces 'custom-loads '(woman))
(put 'ps-print-vertical 'custom-loads '(ps-print))
(put 'supercite-hooks 'custom-loads '(supercite))
(put 'vhdl-menu 'custom-loads '(vhdl-mode))
(put 'chinese-calendar 'custom-loads '(cal-china))
(put 'gnus-newsrc 'custom-loads '(gnus-start))
(put 'erc-replace 'custom-loads '(erc-replace))
(put 'edt 'custom-loads '(edt))
(put 'expand 'custom-loads '(expand))
(put 'erc-paranoia 'custom-loads '(erc))
(put 'bookmark 'custom-loads '(bookmark))
(put 'icon 'custom-loads '(icon))
(put 'nnmail-procmail 'custom-loads '(nnmail))
(put 'cua 'custom-loads '(cua-base))
(put 'desktop 'custom-loads '(desktop))
(put 'eshell-cmpl 'custom-loads '(em-cmpl))
(put 'cperl-help-system 'custom-loads '(cperl-mode))
(put 'ps-print-miscellany 'custom-loads '(ps-print))
(put 'erc-hooks 'custom-loads '(erc erc-netsplit))
(put 'comint-completion 'custom-loads '(comint))
(put 'gnus-score-kill 'custom-loads '(gnus gnus-kill))
(put 'ldap 'custom-loads '(ldap))
(put 'remote-compile 'custom-loads '(rcompile))
(put 'gnus-visual 'custom-loads '(earcon gnus-art gnus-audio gnus smiley))
(put 'dabbrev 'custom-loads '(dabbrev))
(put 'completion 'custom-loads '(completion iswitchb))
(put 'cpp 'custom-loads '(cpp))
(put 'dig 'custom-loads '(dig net-utils))
(put 'ps-print-background 'custom-loads '(ps-print))
(put 'dns-mode 'custom-loads '(dns-mode))
(put 'org-archive 'custom-loads '(org))
(put 'gnus-score-expire 'custom-loads '(gnus-kill gnus-score))
(put 'tramp 'custom-loads '(tramp tramp-ftp tramp-smb))
(put 'supercite-frames 'custom-loads '(supercite))
(put 'dirtrack 'custom-loads '(dirtrack))
(put 'ediff-window 'custom-loads '(ediff-wind ediff-help))
(put 'bruce 'custom-loads '(bruce))
(put 'windows 'custom-loads '(follow windmove winner))
(put 'gnus-exit 'custom-loads '(gnus-group gnus))
(put 'speedbar 'custom-loads '(speedbar sb-image))
(put 'org-link-follow 'custom-loads '(org))
(put 'erc-match 'custom-loads '(erc-match))
(put 'etags 'custom-loads '(etags speedbar))
(put 'f90-indent 'custom-loads '(f90))
(put 'octave-inferior 'custom-loads '(octave-mod octave-inf))
(put 'ebnf-non-terminal 'custom-loads '(ebnf2ps))
(put 'ebnf-terminal 'custom-loads '(ebnf2ps))
(put 'nndiary 'custom-loads '(nndiary))
(put 'gnus-summary-maneuvering 'custom-loads '(gnus-sum))
(put 'gnus-start 'custom-loads '(gnus-start gnus gnus-group gnus-int gnus-util nnheader))
(put 'dcl 'custom-loads '(dcl-mode))
(put 'ogonek 'custom-loads '(ogonek))
(put 'gnus-extract-view 'custom-loads '(gnus-sum gnus-uu))
(put 'dired-keys 'custom-loads '(dired-x))
(put 'lisp-mnt 'custom-loads '(lisp-mnt))
(put 'ediff-mult 'custom-loads '(ediff-mult))
(put 'org-agenda 'custom-loads '(org))
(put 'mpuz 'custom-loads '(mpuz))
(put 'find-file 'custom-loads '(find-file))
(put 'fortran-comment 'custom-loads '(fortran))
(put 'idlwave-online-help 'custom-loads '(idlw-help))
(put 'org-agenda-windows 'custom-loads '(org))
(put 'viper 'custom-loads '(viper-keym viper-init viper-ex viper viper-mous viper-macs viper-util))
(put 'image-dired 'custom-loads '(image-dired))
(put 'ps-print-page 'custom-loads '(ps-print))
(put 'postscript 'custom-loads '(ebnf2ps printing ps-print))
(put 'erc-autojoin 'custom-loads '(erc-join))
(put 'gnus-undo 'custom-loads '(gnus-undo))
(put 'widget-faces 'custom-loads '(wid-edit))
(put 'info-lookup 'custom-loads '(info-look))
(put 'spam-spamoracle 'custom-loads '(spam))
(put 'gnus-various 'custom-loads '(gnus-sum gnus gnus-util))
(put 'elide-head 'custom-loads '(elide-head))
(put 'vhdl-compile 'custom-loads '(vhdl-mode))
(put 'font-lock-highlighting-faces 'custom-loads '(vera-mode verilog-mode))
(put 'ebrowse-tree 'custom-loads '(ebrowse))
(put 'flyspell 'custom-loads '(flyspell))
(put 'python 'custom-loads '(python))
(put 'recentf-filters 'custom-loads '(recentf))
(put 'ange-ftp 'custom-loads '(ange-ftp))
(put 'erc-pcomplete 'custom-loads '(erc-pcomplete))
(put 'verilog-mode-indent 'custom-loads '(verilog-mode))
(put 'erc-stamp 'custom-loads '(erc-stamp))
(put 'ebnf-shape 'custom-loads '(ebnf2ps))
(put 'minibuffer 'custom-loads '(icomplete complete savehist))
(put 'rmail-edit 'custom-loads '(rmailedit))
(put 'gnus-meta 'custom-loads '(gnus))
(put 'mouse-sel 'custom-loads '(mouse-sel))
(put 'sort 'custom-loads '(sort))
(put 'antlr 'custom-loads '(antlr-mode))
(put 'mail-source 'custom-loads '(mail-source nndiary pop3))
(put 'trace 'custom-loads '(trace))
(put 'gnus-article-washing 'custom-loads '(gnus-art))
(put 'org-agenda-daily/weekly 'custom-loads '(org))
(put 'yow 'custom-loads '(yow))
(put 'reftex-defining-label-environments 'custom-loads '(reftex-vars))
(put 'asm 'custom-loads '(asm-mode))
(put 'gnus-score-files 'custom-loads '(gnus-score gnus))
(put 'mail-abbrev 'custom-loads '(mailabbrev))
(put 'grep 'custom-loads '(grep))
(put 'feedmail 'custom-loads '(feedmail))
(put 'gnus-agent 'custom-loads '(gnus gnus-agent))
(put 'message-news 'custom-loads '(message))
(put 'smime 'custom-loads '(smime))
(put 'eshell 'custom-loads '(esh-arg eshell esh-cmd esh-ext esh-io esh-mode esh-module esh-opt esh-proc esh-test esh-util esh-var))
(put 'dired-faces 'custom-loads '(dired))
(put 'erc-track 'custom-loads '(erc-track))
(put 'bib 'custom-loads '(bib-mode))
(put 'vhdl-align 'custom-loads '(vhdl-mode))
(put 'iswitchb 'custom-loads '(isearchb iswitchb))
(put 'flymake 'custom-loads '(flymake))
(put 'custom-buffer 'custom-loads '(cus-edit))
(put 'vhdl-header 'custom-loads '(vhdl-mode))
(put 'eshell-cmd 'custom-loads '(esh-cmd))
(put 'tex-run 'custom-loads '(tex-mode))
(put 'reftex-finding-files 'custom-loads '(reftex-vars))
(put 'gnus-summary-pick 'custom-loads '(gnus-salt))
(put 'gnus-thread 'custom-loads '(gnus-sum gnus-group))
(put 'org-progress 'custom-loads '(org))
(put 'pop3 'custom-loads '(pop3))
(put 'languages 'custom-loads '(ps-mode ada-mode antlr-mode asm-mode cus-edit cfengine cperl-mode dcl-mode delphi f90 fortran hideshow icon idlwave info-look ld-script m4-mode meta-mode modula2 octave-mod pascal perl-mode prolog python sgml-mode sh-script sieve simula tcl vera-mode verilog-mode vhdl-mode))
(put 'reftex-miscellaneous-configurations 'custom-loads '(reftex-vars))
(put 'pong 'custom-loads '(pong))
(put 'ediff-ptch 'custom-loads '(ediff-ptch))
(put 'jka-compr 'custom-loads '(jka-compr))
(put 'development 'custom-loads '(cus-edit))
(put 'ediff 'custom-loads '(ediff-init ediff-diff ediff-mult ediff-ptch ediff ediff-wind))
(put 'feedmail-spray 'custom-loads '(feedmail))
(put 'spam 'custom-loads '(spam))
(put 'allout-encryption 'custom-loads '(allout))
(put 'org-sparse-trees 'custom-loads '(org))
(put 'idlwave-external-programs 'custom-loads '(idlwave))
(put 'strokes 'custom-loads '(strokes))
(put 'calc 'custom-loads '(calc))
(put 'warnings 'custom-loads '(warnings))
(put 'mouse 'custom-loads '(artist avoid goto-addr cus-edit mouse-sel msb strokes))
(put 'nnmail-various 'custom-loads '(nnmail))
(put 'smiley 'custom-loads '(smiley))
(put 'extensions 'custom-loads '(cust-print eldoc ido page-ext sha1 time-stamp wid-edit))
(put 'tetris 'custom-loads '(tetris))
(put 'ebnf-displacement 'custom-loads '(ebnf2ps))
(put 'appt 'custom-loads '(appt))
(put 'url-history 'custom-loads '(url-history))
(put 'erc-netsplit 'custom-loads '(erc-netsplit))
(put 'snmp 'custom-loads '(snmp-mode))
(put 'speedbar-faces 'custom-loads '(speedbar vhdl-mode))
(put 'erc-display 'custom-loads '(erc erc-goodies))
(put 'rmail 'custom-loads '(rmail rmail-spam-filter))
(put 'ps-print-n-up 'custom-loads '(ps-print))
(put 'eshell-arg 'custom-loads '(esh-arg))
(put 'ebnf-syntactic 'custom-loads '(ebnf2ps))
(put 'erc-dcc 'custom-loads '(erc-dcc erc-xdcc))
(put 'sieve-manage 'custom-loads '(sieve-manage))
(put 'idlwave-shell-command-setup 'custom-loads '(idlw-shell))
(put 'ps-print-printer 'custom-loads '(lpr ps-print))
(put 'message-various 'custom-loads '(message))
(put 'rcirc 'custom-loads '(rcirc))
(put 'term 'custom-loads '(terminal term))
(put 'gnus-summary-exit 'custom-loads '(gnus-sum gnus))
(put 'news 'custom-loads '(canlock gnus message mm-decode spam spam-report supercite))
(put 'ada 'custom-loads '(ada-xref ada-mode))
(put 'gnus 'custom-loads '(gnus gnus-art gnus-async gnus-delay gnus-demon gnus-diary gnus-dup gnus-eform gnus-uu deuglify gnus-sieve gnus-soup gnus-undo gnus-win mail-source mm-url nnimap nnmail nntp spam-stat))
(put 'cperl-affected-by-hairy 'custom-loads '(cperl-mode))
(put 'spam-bogofilter 'custom-loads '(spam))
(put 'erc-control-characters 'custom-loads '(erc-goodies))
(put 'eudc-ldap 'custom-loads '(eudc-vars))
(put 'reftex-making-and-inserting-labels 'custom-loads '(reftex-vars))
(put 'erc-button 'custom-loads '(erc-button))
(put 'calendar-hooks 'custom-loads '(calendar))
(put 'mailalias 'custom-loads '(mailalias))
(put 'frames 'custom-loads '(desktop ediff-wind imenu two-column))
(put 'gnus-server 'custom-loads '(gnus nnheader gnus-srvr))
(put 'paren-showing 'custom-loads '(paren))
(put 'dos-fns 'custom-loads '("dos-vars"))
(put 'display-time 'custom-loads '(time))
(put 'multimedia 'custom-loads '(gnus-audio image-dired mm-decode thumbs))
(put 'reftex 'custom-loads '(reftex-vars))
(put 'newsticker-ticker 'custom-loads '(newsticker))
(put 'newsticker-miscellaneous 'custom-loads '(newsticker))
(put 'org-structure 'custom-loads '(org))
(put 'hexl 'custom-loads '(hexl))
(put 'gnus-summary-visual 'custom-loads '(gnus-sum))
(put 'eudc-ph 'custom-loads '(eudc-vars))
(put 'gnus-group-listing 'custom-loads '(gnus-group))
(put 'rmail-reply 'custom-loads '(rmail))
(put 'org-export-ascii 'custom-loads '(org))
(put 'gnus-score 'custom-loads '(gnus-nocem gnus))
(put 'gnus-group-select 'custom-loads '(gnus-sum gnus gnus-group))
(put 'archive-lzh 'custom-loads '(arc-mode))
(put 'eshell-prompt 'custom-loads '(em-prompt "esh-groups"))
(put 'vhdl-sequential-process 'custom-loads '(vhdl-mode))
(put 'simula 'custom-loads '(simula))
(put 'vhdl-comment 'custom-loads '(vhdl-mode))
(put 'message-buffers 'custom-loads '(message))
(put '5x5 'custom-loads '(5x5))
(put 'docs 'custom-loads '(info makeinfo texinfo))
(put 'enriched 'custom-loads '(enriched))
(put 'eshell-alias 'custom-loads '(em-alias))
(put 'url 'custom-loads '(url-vars url-cookie url-gw url-history url-irc url-news))
(put 'gnus-threading 'custom-loads '(gnus-sum))
(put 'hide-ifdef 'custom-loads '(hideif))
(put 'vip 'custom-loads '(vip))
(put 'url-cache 'custom-loads '(url-vars url-cache))
(put 'smerge 'custom-loads '(smerge-mode))
(put 'spell 'custom-loads '(spell))
(put 'electric-help 'custom-loads '(ehelp))
(put 'url-gateway 'custom-loads '(url-gw))
(put 'align 'custom-loads '(align))
(put 'rmail-headers 'custom-loads '(rmail undigest))
(put 'timeclock 'custom-loads '(timeclock))
(put 'gnus-score-decay 'custom-loads '(gnus-score))
(put 'tildify 'custom-loads '(tildify))
(put 'cperl-autoinsert-details 'custom-loads '(cperl-mode))
(put 'help 'custom-loads '(apropos cus-edit ehelp help-fns help-at-pt help-mode info info-look man help-macro tutorial woman))
(put 'forms 'custom-loads '(forms))
(put 'widget-documentation 'custom-loads '(wid-edit))
(put 'ld-script 'custom-loads '(ld-script))
(put 'eshell-banner 'custom-loads '(em-banner))
(put 'artist 'custom-loads '(artist))
(put 'gnus-score-various 'custom-loads '(gnus gnus-score))
(put 'cperl-faces 'custom-loads '(cperl-mode))
(put 'goto-address 'custom-loads '(goto-addr))
(put 'inferior-lisp 'custom-loads '(inf-lisp))
(put 'pgg-gpg 'custom-loads '(pgg-gpg))
(put 'gnus-nocem 'custom-loads '(gnus-nocem))
(put 'gnus-group-visual 'custom-loads '(gnus-group gnus))
(put 'paren-matching 'custom-loads '(paren))
(put 'vc-bzr 'custom-loads '(vc-bzr))
(put 'font-lock 'custom-loads '(hi-lock))
(put 'lazy-highlight 'custom-loads '(ispell))
(put 'tpu 'custom-loads '("tpu-extras" tpu-edt))
(put 'w32 'custom-loads '("w32-vars"))
(put 'viper-hooks 'custom-loads '(viper-init))
(put 'gnus-cite 'custom-loads '(gnus-cite))
(put 'gnus-demon 'custom-loads '(gnus-demon))
(put 'newsticker 'custom-loads '(newsticker))
(put 'reftex-optimizations-for-large-documents 'custom-loads '(reftex-vars))
(put 'viper-misc 'custom-loads '(viper-init viper viper-cmd))
(put 'tmm 'custom-loads '(tmm))
(put 'gnus-message 'custom-loads '(gnus-msg gnus message))
(put 'tls 'custom-loads '(tls))
(put 'org-link-store 'custom-loads '(org))
(put 'feedmail-queue 'custom-loads '(feedmail))
(put 'idlwave-misc 'custom-loads '(idlwave))
(put 'erc-capab 'custom-loads '(erc-capab))
(put 'cmuscheme 'custom-loads '(cmuscheme))
(put 'ansi-colors 'custom-loads '(ansi-color))
(put 'org-export-translation 'custom-loads '(org))
(put 'file-cache 'custom-loads '(filecache))
(put 'uce 'custom-loads '(uce))
(put 'org-tags 'custom-loads '(org))
(put 'starttls 'custom-loads '(starttls))
(put 'org-remember 'custom-loads '(org))
(put 'org-export-html 'custom-loads '(org))
(put 'matching 'custom-loads '(bookmark completion ffap imenu))
(put 'custom-faces 'custom-loads '(cus-edit))
(put 'smtpmail 'custom-loads '(smtpmail))
(put 'lisp-indent 'custom-loads '("cl-indent"))
(put 'midnight 'custom-loads '(midnight))
(put 'tex 'custom-loads '(bibtex tex-mode reftex-vars))
(put 'cperl-indentation-details 'custom-loads '(cperl-mode))
(put 'mail-extr 'custom-loads '(mail-extr))
(put 'filesets 'custom-loads '(filesets))
(put 'double 'custom-loads '(double))
(put 'allout-developer 'custom-loads '(allout))
(put 'imenu 'custom-loads '(imenu))
(put 'eshell-var 'custom-loads '(esh-var))
(put 'eshell-smart 'custom-loads '(em-smart))
(put 'server 'custom-loads '(server))
(put 'org-export 'custom-loads '(org))
(put 'org-priorities 'custom-loads '(org))
(put 'idlwave-shell-highlighting-and-faces 'custom-loads '(idlw-shell))
(put 'verilog-mode-auto 'custom-loads '(verilog-mode))
(put 'tcl 'custom-loads '(tcl))
(put 'vhdl-print 'custom-loads '(vhdl-mode))
(put 'url-mime 'custom-loads '(url-vars))
(put 'artist-text 'custom-loads '(artist))
(put 'gnus-summary-tree 'custom-loads '(gnus-salt))
(put 'tar 'custom-loads '(tar-mode))
(put 'url-hairy 'custom-loads '(url-vars url-util))
(put 'archive 'custom-loads '(arc-mode))
(put 'PostScript-interaction 'custom-loads '(ps-mode))
(put 'idlwave-abbrev-and-indent-action 'custom-loads '(idlwave))
(put 'ps-print 'custom-loads '(ps-print))
(put 'erc-networks 'custom-loads '(erc-networks))
(put 'ezimage 'custom-loads '(ezimage))
(put 'calendar-html 'custom-loads '(cal-html))
(put 'view 'custom-loads '(calendar view))
(put 'cwarn 'custom-loads '(cwarn))
(put 'org-startup 'custom-loads '(org))
(put 'testcover 'custom-loads '(testcover))
(put 'gnus-score-default 'custom-loads '(gnus-sum gnus-score))
(put 'ebnf-except 'custom-loads '(ebnf2ps))
(put 'nnmail-duplicate 'custom-loads '(nnmail))
(put 'handwrite 'custom-loads '(handwrite))
(put 'ses 'custom-loads '(ses))
(put 'eshell-proc 'custom-loads '(esh-proc))
(put 'gnus-format 'custom-loads '(gnus-spec))
(put 'custom-browse 'custom-loads '(cus-edit))
(put 'mime 'custom-loads '(mailcap mm-bodies mm-util mm-encode pgg-def rfc1843 smime))
(put 'org-table-calculation 'custom-loads '(org))
(put 'generic-x 'custom-loads '(generic-x))
(put 'gnus-delay 'custom-loads '(gnus-delay))
(put 'partial-completion 'custom-loads '(complete))
(put 'whitespace 'custom-loads '(whitespace))
(put 'maint 'custom-loads '(emacsbug gulp lisp-mnt))
(put 'pages 'custom-loads '(page-ext))
(put 'message-interface 'custom-loads '(message))
(put 'diary 'custom-loads '(calendar diary-lib solar))
(put 'custom-magic-faces 'custom-loads '(cus-edit))
(put 'emacsbug 'custom-loads '(emacsbug))
(put 'tex-view 'custom-loads '(tex-mode))
(put 'nnmail-files 'custom-loads '(nnmail))
(put 'gnus-edit-form 'custom-loads '(gnus-eform))
(put 'org-keywords 'custom-loads '(org))
(put 'gnus-audio 'custom-loads '(gnus-audio))
(put 'modula2 'custom-loads '(modula2))
(put 'ps-print-color 'custom-loads '(ps-print))
(put 'gnus-diary 'custom-loads '(gnus-diary nndiary))
(put 'emacs 'custom-loads '(cus-edit ebnf2ps))
(put 'comint 'custom-loads '(comint))
(put 'reftex-fontification-configurations 'custom-loads '(reftex-vars))
(put 'auto-insert 'custom-loads '(autoinsert))
(put 'abbrev 'custom-loads '(cus-edit dabbrev expand hippie-exp quickurl))
(put 'ediff-merge 'custom-loads '(ediff-init ediff-merg))
(put 'reveal 'custom-loads '(reveal))
(put 'vhdl 'custom-loads '(vhdl-mode))
(put 'gnus-summary-mail 'custom-loads '(gnus-sum))
(put 'ebnf-optimization 'custom-loads '(ebnf2ps))
(put 'apropos 'custom-loads '(apropos))
(put 'gomoku 'custom-loads '(gomoku))
(put 'eshell-pred 'custom-loads '(em-pred))
(put 'tools 'custom-loads '(calculator add-log compare-w compile copyright diff diff-mode ebrowse ediff elide-head emerge etags glasses grep gud make-mode pcvs-defs rcompile sieve smerge-mode speedbar tempo vc which-func))
(put 'gnus-topic 'custom-loads '(gnus-topic))
(put 'sgml 'custom-loads '(sgml-mode))
(put 'keyboard 'custom-loads '(chistory keypad kmacro type-break))
(put 'vhdl-project 'custom-loads '(vhdl-mode))
(put 'eshell-hist 'custom-loads '(em-hist))
(put 'viper-mouse 'custom-loads '(viper-mous))
(put 'ps-print-horizontal 'custom-loads '(ps-print))
(put 'erc-server-hooks 'custom-loads '(erc))
(put 'woman 'custom-loads '(woman))
(put 'decipher 'custom-loads '(decipher))
(put 'pcmpl-gnu 'custom-loads '(pcmpl-gnu))
(put 'org-export-tables 'custom-loads '(org))
(put 'ps-print-face 'custom-loads '(ps-print))
(put 'org-reveal-location 'custom-loads '(org))
(put 'rmail-summary 'custom-loads '(rmail rmailsum))
(put 'metamail 'custom-loads '(metamail))
(put 'winner 'custom-loads '(winner))
(put 'org-agenda-prefix 'custom-loads '(org))
(put 'ebrowse-faces 'custom-loads '(ebrowse))
(put 'org-agenda-skip 'custom-loads '(org))
(put 'org-font-lock 'custom-loads '(org))
(put 'wp 'custom-loads '(bib-mode ebnf2ps enriched lpr nroff-mode printing ps-print refbib refer table cus-edit tildify view))
(put 'reftex-citation-support 'custom-loads '(reftex-vars))
(put 'gnus-summary-choose 'custom-loads '(gnus-sum))
(put 'sha1 'custom-loads '(sha1))
(put 'widget-browse 'custom-loads '(wid-browse))
(put 'feedmail-misc 'custom-loads '(feedmail))
(put 'diff 'custom-loads '(diff diff-mode))
(put 'unix 'custom-loads '(gud rlogin sh-script shell term))
(put 'external 'custom-loads '(bib-mode locate cus-edit server))
(put 'vc 'custom-loads '(log-edit vc vc-arch vc-bzr vc-cvs vc-hg vc-mcvs vc-mtn vc-rcs vc-sccs vc-svn))
(put 'vhdl-highlight-faces 'custom-loads '(vhdl-mode))
(put 'which-func 'custom-loads '(which-func))
(put 'icalendar 'custom-loads '(icalendar))
(put 'pc-select 'custom-loads '(pc-select))
(put 'vera 'custom-loads '(vera-mode))
(put 'i18n 'custom-loads '(ccl double iso-ascii latin1-disp cus-edit ogonek url-vars))
(put 'org 'custom-loads '(org))
(put 'sh 'custom-loads '(sh-script))
(put 'message-headers 'custom-loads '(message))
(put 'idlwave-code-formatting 'custom-loads '(idlwave))
(put 'basic-faces 'custom-loads '(cus-edit shadowfile))
(put 'net-utils 'custom-loads '(net-utils))
(put 'vhdl-naming 'custom-loads '(vhdl-mode))
(put 'columns 'custom-loads '(delim-col))
(put 'pp 'custom-loads '(pp))
(put 'two-column 'custom-loads '(two-column))
(put 'erc-hecomplete 'custom-loads '(erc-hecomplete))
(put 'log-edit 'custom-loads '(log-edit))
(put 'pgg 'custom-loads '(pgg-def pgg-gpg pgg-parse pgg-pgp pgg-pgp5))
(put 'message-forwarding 'custom-loads '(message))
(put 'help-at-pt 'custom-loads '(help-at-pt))
(put 'message-faces 'custom-loads '(message))
(put 'ibuffer 'custom-loads '(ibuffer ibuf-ext))
(put 'environment 'custom-loads '(cus-edit dired "dos-vars" "w32-vars"))
(put 'perl 'custom-loads '(perl-mode))
(put 'erc-server 'custom-loads '(erc-backend))
(put 'vhdl-port 'custom-loads '(vhdl-mode))
(put 'gnus-charset 'custom-loads '(gnus gnus-group gnus-sum))
(put 'calculator 'custom-loads '(calculator))
(put 'conf 'custom-loads '(conf-mode))
(put 'custom-menu 'custom-loads '(cus-edit))
(put 'comm 'custom-loads '(dig eudc-vars ldap net-utils tls))
(put 'type-break 'custom-loads '(type-break))
(put 'convenience 'custom-loads '(autoinsert autorevert bs calculator completion cua-base dabbrev ffap filecache filesets follow hippie-exp ibuffer ido imenu iswitchb kmacro master complete pc-select repeat ruler-mode speedbar whitespace windmove))
(put 'lm 'custom-loads '(landmark))
(put 'org-agenda-time-grid 'custom-loads '(org))
(put 'ruler-mode 'custom-loads '(ruler-mode))
(put 'idlwave-routine-info 'custom-loads '(idlwave))
(put 'm4 'custom-loads '(m4-mode))
(put 'gnus-article-mime 'custom-loads '(gnus-sum gnus-art mm-uu))
(put 'erc-services 'custom-loads '(erc-services))
(put 'emulations 'custom-loads '(crisp cua-base edt tpu-edt vip viper))
(put 'vhdl-speedbar 'custom-loads '(vhdl-mode))
(put 'games 'custom-loads '(5x5 bruce decipher dunnet fortune gametree gomoku handwrite hanoi landmark mpuz pong solitaire spook tetris yow))
(put 'nnmail-retrieve 'custom-loads '(nnmail))
(put 'gnus-duplicate 'custom-loads '(gnus-dup))
(put 'wdired 'custom-loads '(wdired))
(put 'hi-lock 'custom-loads '(hi-lock))
(put 'find-function 'custom-loads '(find-func))
(put 'menu 'custom-loads '(easymenu cus-edit tmm))
(put 'eshell-test 'custom-loads '(esh-test))
(put 'vhdl-highlight 'custom-loads '(vhdl-mode))
(put 'widgets 'custom-loads '(tree-widget wid-browse wid-edit))
(put 'url-cookie 'custom-loads '(url-cookie))
(put 'erc-ignore 'custom-loads '(erc))
(put 'log-view 'custom-loads '(log-view))
(put 'mime-security 'custom-loads '(gnus-art mm-decode mml2015))
(put 'PostScript 'custom-loads '(ps-mode))
(put 'abbrev-mode 'custom-loads '(cus-edit mailabbrev))
(put 'eshell-term 'custom-loads '(em-term))
(put 'earcon 'custom-loads '(earcon))
(put 'feedmail-headers 'custom-loads '(feedmail))
(put 'newsticker-faces 'custom-loads '(newsticker))
(put 'hypermedia 'custom-loads '(browse-url goto-addr metamail org url-vars wid-edit))
(put 'sieve 'custom-loads '(sieve-mode sieve))
(put 'image 'custom-loads '(iimage image-file))
(put 'ff 'custom-loads '(find-file))
(put 'prolog 'custom-loads '(prolog))
(put 'follow 'custom-loads '(follow))
(put 'info 'custom-loads '(info))
(put 'battery 'custom-loads '(battery))
(put 'texinfo 'custom-loads '(texinfo))
(put 'dired-mark 'custom-loads '(dired))
(put 'makeinfo 'custom-loads '(makeinfo))
(put 'supercite-cite 'custom-loads '(supercite))
(put 'speedbar-vc 'custom-loads '(speedbar))
(put 'msb 'custom-loads '(msb))
(put 'save-place 'custom-loads '(saveplace))
(put 'mode-line-faces 'custom-loads '(time cus-edit))
(put 'bs 'custom-loads '(bs))
(put 'eldoc 'custom-loads '(eldoc))
(put 'change-log 'custom-loads '(add-log))
(put 'gnus-sieve 'custom-loads '(gnus-sieve))
(put 'gnus-group-levels 'custom-loads '(gnus-start gnus gnus-group))
(put 'cperl 'custom-loads '(cperl-mode))
(put 'longlines 'custom-loads '(longlines))
(put 'bs-appearance 'custom-loads '(bs))
(put 'nil 'custom-loads '(css-mode))
(put 'pcmpl-cvs 'custom-loads '(pcmpl-cvs))
(put 'eshell-mode 'custom-loads '(esh-mode))
(put 'files 'custom-loads '(ange-ftp autoinsert autorevert cus-edit dired filecache latexenc recentf shadowfile tramp))
(put 'mm-url 'custom-loads '(mm-url))
(put 'pcl-cvs 'custom-loads '(pcvs-defs pcvs-info pcvs pcvs-parse cvs-status log-edit log-view))
(put 'rmail-files 'custom-loads '(rmail))
(put 'gnus-summary-format 'custom-loads '(gnus-diary gnus gnus-sum))
(put 'windmove 'custom-loads '(windmove))
(put 'terminals 'custom-loads '(terminal))
(put 'avoid 'custom-loads '(avoid))
(put 'gnus-soup 'custom-loads '(gnus-soup))
(put 'table-hooks 'custom-loads '(table))
(put 'sh-indentation 'custom-loads '(sh-script))
(put 'ebnf-production 'custom-loads '(ebnf2ps))
(put 'gnus-files 'custom-loads '(gnus nnmail))
(put 'gnus-windows 'custom-loads '(gnus-win))
(put 'reftex-label-support 'custom-loads '(reftex-vars))
(put 'gnus-article-buttons 'custom-loads '(gnus-art))
(put 'gnus-summary 'custom-loads '(gnus-sum gnus))
(put 'compilation 'custom-loads '(compile))
(put 'erc-ezbounce 'custom-loads '(erc-ezbounce))
(put 'ediff-highlighting 'custom-loads '(ediff-init))
(put 'idlwave-shell-general-setup 'custom-loads '(idlw-shell idlwave))
(put 'xscheme 'custom-loads '(xscheme))
(put 'checkdoc 'custom-loads '(checkdoc))
(put 'gnus-article-hiding 'custom-loads '(gnus-cite gnus-art gnus-sum))
(put 'vhdl-mode 'custom-loads '(vhdl-mode))
(put 'lpr 'custom-loads '(lpr))
(put 'verilog-mode 'custom-loads '(verilog-mode))
(put 'ispell 'custom-loads '(flyspell ispell))
(put 'auto-revert 'custom-loads '(autorevert))
(put 'advice 'custom-loads '(advice))
(put 'picture 'custom-loads '(picture))
(put 'eshell-util 'custom-loads '(esh-util))
(put 'gnus-group 'custom-loads '(gnus gnus-group gnus-topic))
(put 'ediff-vers 'custom-loads '(ediff-vers))
(put 'eudc-bbdb 'custom-loads '(eudc-vars))
(put 'reftex-referencing-labels 'custom-loads '(reftex-vars))
(put 'gnus-article-various 'custom-loads '(gnus-art gnus-sum))
(put 'imap 'custom-loads '(imap))
(put 'ediff-diff 'custom-loads '(ediff-diff))
(put 'ebnf-repeat 'custom-loads '(ebnf2ps))
(put 'supercite 'custom-loads '(supercite))
(put 'ps-print-headers 'custom-loads '(ps-print))
(put 'gnus-summary-marks 'custom-loads '(gnus-sum gnus))
(put 'bibtex-autokey 'custom-loads '(bibtex))
(put 'eudc 'custom-loads '(eudc-vars))
(put 'octave 'custom-loads '(octave-mod octave-inf))
(put 'editing-basics 'custom-loads '(cua-base pc-select))
(put 'kmacro 'custom-loads '(kmacro))
(put 'fortune-signature 'custom-loads '(fortune))
(put 'newsticker-layout 'custom-loads '(newsticker))
(put 'nnmail-expire 'custom-loads '(nnmail))
(put 'gnus-article-saving 'custom-loads '(gnus gnus-art))
(put 'icomplete 'custom-loads '(icomplete))
(put 'LaTeX 'custom-loads '(reftex-vars))
(put 'org-link 'custom-loads '(org))
(put 'socks 'custom-loads '(socks))
(put 'man 'custom-loads '(man))
(put 'solitaire 'custom-loads '(solitaire))
(put 'erc-page 'custom-loads '(erc-page))
(put 'hippie-expand 'custom-loads '(hippie-exp))
(put 'refer 'custom-loads '(refer))
(put 'message-mail 'custom-loads '(message))
(put 'archive-zoo 'custom-loads '(arc-mode))
(put 'idlwave-completion 'custom-loads '(idlwave))
(put 'eshell-rebind 'custom-loads '(em-rebind))
(put 'bibtex 'custom-loads '(bibtex bibtex-style))
(put 'faces 'custom-loads '(cus-edit cwarn dired gnus hi-lock hilit-chg message paren ps-print rcirc speedbar whitespace wid-edit woman))
(put 'gnus-summary-various 'custom-loads '(gnus-sum))
(put 'applications 'custom-loads '(calc calendar erc eshell cus-edit ispell newsticker rcirc ses spell uniquify))
(put 'ebrowse-member 'custom-loads '(ebrowse))
(put 'erc-fill 'custom-loads '(erc-fill))
(put 'terminal 'custom-loads '(terminal))
(put 'org-export-icalendar 'custom-loads '(org))
(put 'shadow 'custom-loads '(shadowfile))
(put 'hl-line 'custom-loads '(hl-line))
(put 'eshell-glob 'custom-loads '(em-glob))
(put 'internal 'custom-loads '(cus-edit delim-col))
(put 'lisp 'custom-loads '(advice bytecomp checkdoc cust-print edebug eldoc elp find-func gmm-utils ielm inf-lisp "cl-indent" shadow pp re-builder unsafep scheme testcover trace warnings xscheme))
(put 'vhdl-testbench 'custom-loads '(vhdl-mode))
(put 'local 'custom-loads '(calendar))
(put 'rlogin 'custom-loads '(rlogin))
(put 'erc-faces 'custom-loads '(erc-goodies erc erc-button erc-capab erc-match erc-stamp))
(put 'debugger 'custom-loads '(debug))
(put 'erc-ibuffer 'custom-loads '(erc-ibuffer))
(put 'archive-zip 'custom-loads '(arc-mode))
(put 'erc-notify 'custom-loads '(erc-notify))
(put 'gnus-registry 'custom-loads '(gnus-registry))
(put 'gnus-start-server 'custom-loads '(gnus-start))
(put 'debug 'custom-loads '(debug))
(put 'tree-widget 'custom-loads '(tree-widget))
(put 'canlock 'custom-loads '(canlock))
(put 'gnus-extract-archive 'custom-loads '(gnus-uu))
(put 'message 'custom-loads '(footnote message mml mml-sec))
(put 'message-sending 'custom-loads '(message))
(put 'archive-arc 'custom-loads '(arc-mode))
(put 'editing 'custom-loads '(cus-edit hl-line outline picture reveal table vcursor view))
(put 'rmail-output 'custom-loads '(rmailout))
(put 'erc-scripts 'custom-loads '(erc))
(put 'crisp 'custom-loads '(crisp))
(put 'nroff 'custom-loads '(nroff-mode))
(put 'gnus-group-icons 'custom-loads '(gnus-group))
(put 'erc-buffers 'custom-loads '(erc))
(put 'executable 'custom-loads '(executable))
(put 'gnus-score-adapt 'custom-loads '(gnus-score gnus))
(put 'copyright 'custom-loads '(copyright))
(put 'bytecomp 'custom-loads '(bytecomp))
(put 'url-file 'custom-loads '(url-cache url-cookie url-vars))
(put 'message-insertion 'custom-loads '(message))
(put 'pcmpl-unix 'custom-loads '(pcmpl-unix))
(put 'table 'custom-loads '(table))
(put 'gnus-extract-post 'custom-loads '(gnus-uu))
(put 'reftex-viewing-cross-references 'custom-loads '(reftex-vars))
(put 'verilog-mode-actions 'custom-loads '(verilog-mode))
(put 'hanoi 'custom-loads '(hanoi))
(put 'reftex-index-support 'custom-loads '(reftex-vars))
(put 'rmail-retrieve 'custom-loads '(rmail rmailsum))
(put 'pascal 'custom-loads '(pascal))
(put 'org-todo 'custom-loads '(org))
(put 'data 'custom-loads '(arc-mode conf-mode dns-mode forms generic-x hexl saveplace snmp-mode sort tar-mode time-stamp timeclock))
(put 'mail 'custom-loads '(time emacsbug eudc-vars feedmail fortune gnus imap mail-extr mail-hist mail-utils mailalias mailclient message metamail mm-decode mspools pop3 rmail sendmail sieve-manage smtpmail spam spam-report starttls supercite uce))
(put 'erc-log 'custom-loads '(erc-log))
(put 'gnus-summary-sort 'custom-loads '(gnus-sum))
(put 'org-agenda-startup 'custom-loads '(org))
(put 'gnus-group-new 'custom-loads '(gnus-start))
(put 'viper-highlighting 'custom-loads '(viper-init))
(put 'customize 'custom-loads '(cus-edit wid-edit))
(put 'dired 'custom-loads '(dired dired-aux dired-x find-dired ls-lisp wdired))
(put 'recentf 'custom-loads '(recentf))
(put 'erc-identd 'custom-loads '(erc-identd))
(put 'fill 'custom-loads '(align newcomment longlines refill table))
(put 'vhdl-compose 'custom-loads '(vhdl-mode))
(put 'outlines 'custom-loads '(allout org outline))
(put 'latin1-display 'custom-loads '(latin1-disp))
(put 'paragraphs 'custom-loads '(table))
(put 'vhdl-model 'custom-loads '(vhdl-mode))
(put 'ebrowse 'custom-loads '(ebrowse))
(put 'nnmail-split 'custom-loads '(nndiary nnmail))
(put 'makefile 'custom-loads '(make-mode))
(put 'supercite-attr 'custom-loads '(supercite))
(put 'org-export-general 'custom-loads '(org))
(put 'gnus-server-visual 'custom-loads '(gnus-srvr))
(put 'fortune 'custom-loads '(fortune))
(put 'whitespace-faces 'custom-loads '(whitespace))
(put 'diff-mode 'custom-loads '(diff-mode))
(put 'gnus-asynchronous 'custom-loads '(gnus-async))
(put 'woman-formatting 'custom-loads '(woman))
(put 'vcursor 'custom-loads '(vcursor))
(put 'iso-ascii 'custom-loads '(iso-ascii))
(put 'lisp-shadow 'custom-loads '(shadow))
(put 'gnus-dribble-file 'custom-loads '(gnus-start))
(put 'widget-button 'custom-loads '(wid-edit))
(put 'dframe 'custom-loads '(dframe))
(put 'uniquify 'custom-loads '(uniquify))
(put 'erc-autoaway 'custom-loads '(erc-autoaway))
(put 'ps-print-font 'custom-loads '(ps-print ps-mule))
(put 'eshell-basic 'custom-loads '(em-basic))
(put 'vhdl-misc 'custom-loads '(vhdl-mode))
(put 'rmail-obsolete 'custom-loads '(rmail))
(put 'nntp 'custom-loads '(nntp))
(put 'dired-x 'custom-loads '(dired-x))
(put 'spook 'custom-loads '(spook))
(put 'tex-file 'custom-loads '(tex-mode))
(put 'eshell-dirs 'custom-loads '(em-dirs))
(put 'time-stamp 'custom-loads '(time-stamp))
(put 'todo 'custom-loads '(todo-mode))
(put 'rmail-spam-filter 'custom-loads '(rmail-spam-filter))
(put 'org-edit-structure 'custom-loads '(org))
(put 'ebnf-special 'custom-loads '(ebnf2ps))
(put 'gnus-article-highlight 'custom-loads '(gnus-art))
(put 'isearchb 'custom-loads '(isearchb))
(put 'ido 'custom-loads '(ido))
(put 'tooltip 'custom-loads '(gud))
(put 'gud 'custom-loads '(gdb-ui gud))
(put 'c-macro 'custom-loads '(cmacexp))
(put 'gnus-cache 'custom-loads '(gnus-cache gnus))
(put 'eshell-module 'custom-loads '("esh-groups" esh-module))
(put 'gnus-picon 'custom-loads '(gnus-art gnus gnus-picon))
(put 'gnus-extract 'custom-loads '(binhex gnus-uu gnus uudecode))
(put 'gnus-outlook-deuglify 'custom-loads '(deuglify))
(put 'quickurl 'custom-loads '(quickurl))
(put 'compare-windows 'custom-loads '(compare-w))
(put 'browse-url 'custom-loads '(browse-url))
(put 'cust-print 'custom-loads '(cust-print))
(put 'gnus-article 'custom-loads '(gnus-art gnus-cite))
(put 'fortran-indent 'custom-loads '(fortran))
(put 'org-table-editing 'custom-loads '(org))
(put 'nnimap 'custom-loads '(nnimap))
(put 'pgg-parse 'custom-loads '(pgg-parse))
(put 'comment 'custom-loads '(newcomment))
(put 'BibTeX 'custom-loads '(bibtex))
(put 'hardware 'custom-loads '(battery))
(put 'edebug 'custom-loads '(edebug))
(put 'org-agenda-custom-commands 'custom-loads '(org))
(put 'emerge 'custom-loads '(emerge))
(put 'scheme 'custom-loads '(cmuscheme scheme))
(put 'spam-report 'custom-loads '(spam-report))
(put 'org-cycle 'custom-loads '(org))
(put 'gametree 'custom-loads '(gametree))
(put 'newsticker-hooks 'custom-loads '(newsticker))
(put 'gmm 'custom-loads '(gmm-utils))
(put 'gnus-group-foreign 'custom-loads '(gnus-msg gnus-group))
(put 'org-plain-lists 'custom-loads '(org))
(put 'pgg-pgp5 'custom-loads '(pgg-pgp5))
(put 'erc-spelling 'custom-loads '(erc-spelling))
(put 'sh-script 'custom-loads '(sh-script))
(put 'cperl-speed 'custom-loads '(cperl-mode))
(put 'PostScript-edit 'custom-loads '(ps-mode))
(put 'calendar 'custom-loads '(calendar cal-dst cal-html solar icalendar midnight org todo-mode))
(put 'rcirc-faces 'custom-loads '(rcirc))
(put 'spam-ifile 'custom-loads '(spam))
(put 'programming 'custom-loads '(cus-edit))
(put 'meta-font 'custom-loads '(meta-mode))
(put 'ps-print-zebra 'custom-loads '(ps-print))
(put 'newsticker-feed 'custom-loads '(newsticker))
(put 'eshell-unix 'custom-loads '(em-unix))
(put 'org-faces 'custom-loads '(org))
(put 'hi-lock-faces 'custom-loads '(hi-lock))
(put 'hideshow 'custom-loads '(hideshow))
(put 'mailcap 'custom-loads '(mailcap))
(put 'viper-search 'custom-loads '(viper-init))
(put 'printing 'custom-loads '(printing))
(put 'ls-lisp 'custom-loads '(ls-lisp))
(put 'mule 'custom-loads '(descr-text kkc latexenc))
(put 'org-latex 'custom-loads '(org))
(put 'glasses 'custom-loads '(glasses))
(put 'vhdl-style 'custom-loads '(vhdl-mode))
(put 'tempo 'custom-loads '(tempo))
(put 'erc-quit-and-part 'custom-loads '(erc))
(put 'c 'custom-loads '("cc-vars" cmacexp cpp hideif))
(put 'nnmail-prepare 'custom-loads '(nnmail))
(put 'processes 'custom-loads '(sql ansi-color comint compile executable cus-edit flyspell grep metamail pcomplete rcompile rlogin shell socks term))
(put 'ebnf2ps 'custom-loads '(ebnf2ps))
(put 'erc-mode-line-and-header 'custom-loads '(erc))
(put 'sendmail 'custom-loads '(sendmail))
(put 'gnus-article-signature 'custom-loads '(gnus-art))
(put 'eshell-ls 'custom-loads '(em-ls))
(put 'idlwave 'custom-loads '(idlwave idlw-help idlw-shell))
(put 'erc-speedbar 'custom-loads '(erc-speedbar))
(put 'thumbs 'custom-loads '(thumbs))
(put 'newsticker-headline-processing 'custom-loads '(newsticker))
(put 'erc-sound 'custom-loads '(erc-sound))
(put 'erc-truncate 'custom-loads '(erc-truncate))
(put 'viper-ex 'custom-loads '(viper-ex))
(put 'gulp 'custom-loads '(gulp))
(put 'leim 'custom-loads '(quail))
(put 'ielm 'custom-loads '(ielm))
(put 'erc 'custom-loads '(erc-autoaway erc-join erc erc-button erc-capab erc-goodies erc-dcc erc-ezbounce erc-fill erc-hecomplete erc-ibuffer erc-identd erc-log erc-match erc-netsplit erc-networks erc-notify erc-page erc-pcomplete erc-replace erc-services erc-sound erc-speedbar erc-stamp erc-track erc-truncate))
(put 'org-table-settings 'custom-loads '(org))
(put 'find-dired 'custom-loads '(find-dired))
(put 'delphi 'custom-loads '(delphi))
(put 're-builder 'custom-loads '(re-builder))
(put 'eshell-io 'custom-loads '(esh-io))
(put 'killing 'custom-loads '("w32-vars"))
(put 'cfengine 'custom-loads '(cfengine))
(put 'woman-interface 'custom-loads '(woman))
(put 'pgg-pgp 'custom-loads '(pgg-pgp))
(put 'gnus-group-various 'custom-loads '(gnus-group gnus gnus-start))
(put 'org-agenda-sorting 'custom-loads '(org))
;; These are for handling :version.  We need to have a minimum of
;; information so `customize-changed-options' could do its job.

;; For groups we set `custom-version', `group-documentation' and
;; `custom-tag' (which are shown in the customize buffer), so we
;; don't have to load the file containing the group.

;; `custom-versions-load-alist' is an alist that has as car a version
;; number and as elts the files that have variables or faces that
;; contain that version. These files should be loaded before showing
;; the customization buffer that `customize-changed-options'
;; generates.

;; This macro is used so we don't modify the information about
;; variables and groups if it's already set. (We don't know when
;; cus-load.el is going to be loaded and at that time some of the
;; files might be loaded and some others might not).
(defmacro custom-put-if-not (symbol propname value)
  `(unless (get ,symbol ,propname)
     (put ,symbol ,propname ,value)))

(custom-put-if-not 'mime-display 'custom-version "21.1")
(custom-put-if-not 'mime-display 'group-documentation "Display of MIME in mail and news articles.")
(custom-put-if-not 'SQL 'custom-version "20.4")
(custom-put-if-not 'SQL 'group-documentation "Running a SQL interpreter from within Emacs buffers.")
(custom-put-if-not 'spam-stat 'custom-version "22.1")
(custom-put-if-not 'spam-stat 'group-documentation "Statistical spam detection for Emacs.
Use the functions to build a dictionary of words and their statistical
distribution in spam and non-spam mails.  Then use a function to determine
whether a buffer contains spam or not.")
(custom-put-if-not 'paren-showing-faces 'custom-version "22.1")
(custom-put-if-not 'paren-showing-faces 'group-documentation "Group for faces of Show Paren mode.")
(custom-put-if-not 'iimage 'custom-version "22.1")
(custom-put-if-not 'iimage 'group-documentation "Support for inline images.")
(custom-put-if-not 'footnote 'custom-version "21.1")
(custom-put-if-not 'footnote 'group-documentation "Support for footnotes in mail and news messages.")
(custom-put-if-not 'pcomplete 'custom-version "21.1")
(custom-put-if-not 'pcomplete 'group-documentation "Programmable completion.")
(custom-put-if-not 'savehist 'custom-version "22.1")
(custom-put-if-not 'savehist 'group-documentation "Save minibuffer history.")
(custom-put-if-not 'ps-print-vertical 'custom-version "20")
(custom-put-if-not 'ps-print-vertical 'group-documentation "Vertical page layout.")
(custom-put-if-not 'ps-print-vertical 'custom-tag "Vertical")
(custom-put-if-not 'cua 'custom-version "22.1")
(custom-put-if-not 'cua 'group-documentation "Emulate CUA key bindings including C-x and C-c.")
(custom-put-if-not 'ps-print-miscellany 'custom-version "20")
(custom-put-if-not 'ps-print-miscellany 'group-documentation "Miscellany customization.")
(custom-put-if-not 'ps-print-miscellany 'custom-tag "Miscellany")
(custom-put-if-not 'ldap 'custom-version "21.1")
(custom-put-if-not 'ldap 'group-documentation "Lightweight Directory Access Protocol.")
(custom-put-if-not 'ps-print-background 'custom-version "20")
(custom-put-if-not 'ps-print-background 'group-documentation "Background customization.")
(custom-put-if-not 'ps-print-background 'custom-tag "Background")
(custom-put-if-not 'tramp 'custom-version "22.1")
(custom-put-if-not 'tramp 'group-documentation "Edit remote files with a combination of rsh and rcp or similar programs.")
(custom-put-if-not 'ebnf-non-terminal 'custom-version "20")
(custom-put-if-not 'ebnf-non-terminal 'group-documentation "Non-Terminal customization.")
(custom-put-if-not 'ebnf-non-terminal 'custom-tag "Non-Terminal")
(custom-put-if-not 'ebnf-terminal 'custom-version "20")
(custom-put-if-not 'ebnf-terminal 'group-documentation "Terminal customization.")
(custom-put-if-not 'ebnf-terminal 'custom-tag "Terminal")
(custom-put-if-not 'nndiary 'custom-version "22.1")
(custom-put-if-not 'nndiary 'group-documentation "The Gnus Diary back end.")
(custom-put-if-not 'ps-print-page 'custom-version "20")
(custom-put-if-not 'ps-print-page 'group-documentation "Page customization.")
(custom-put-if-not 'ps-print-page 'custom-tag "Page")
(custom-put-if-not 'postscript 'custom-version "20")
(custom-put-if-not 'postscript 'group-documentation "PostScript Group.")
(custom-put-if-not 'postscript 'custom-tag "PostScript")
(custom-put-if-not 'elide-head 'custom-version "21.1")
(custom-put-if-not 'elide-head 'group-documentation "Eliding copyright headers and the like in source files.")
(custom-put-if-not 'master 'custom-version "22.1")
(custom-put-if-not 'master 'group-documentation "Support for master/slave relationships between buffers.")
(custom-put-if-not 'python 'custom-version "22.1")
(custom-put-if-not 'python 'group-documentation "Silly walks in the Python language.")
(custom-put-if-not 'ebnf-shape 'custom-version "20")
(custom-put-if-not 'ebnf-shape 'group-documentation "Shapes customization.")
(custom-put-if-not 'ebnf-shape 'custom-tag "Shape")
(custom-put-if-not 'mail-source 'custom-version "21.1")
(custom-put-if-not 'mail-source 'group-documentation "The mail-fetching library.")
(custom-put-if-not 'eshell 'custom-version "21.1")
(custom-put-if-not 'eshell 'group-documentation "Eshell is a command shell implemented entirely in Emacs Lisp.  It
invokes no external processes beyond those requested by the user.  It
is intended to be a functional replacement for command shells such as
bash, zsh, rc, 4dos; since Emacs itself is capable of handling most of
the tasks accomplished by such tools.")
(custom-put-if-not 'eshell 'custom-tag "The Emacs shell")
(custom-put-if-not 'warnings 'custom-version "22.1")
(custom-put-if-not 'warnings 'group-documentation "Log and display warnings.")
(custom-put-if-not 'ebnf-displacement 'custom-version "20")
(custom-put-if-not 'ebnf-displacement 'group-documentation "Displacement customization.")
(custom-put-if-not 'ebnf-displacement 'custom-tag "Displacement")
(custom-put-if-not 'snmp 'custom-version "20.4")
(custom-put-if-not 'snmp 'group-documentation "Mode for editing SNMP MIB files.")
(custom-put-if-not 'ps-print-n-up 'custom-version "20")
(custom-put-if-not 'ps-print-n-up 'group-documentation "N-up customization.")
(custom-put-if-not 'ps-print-n-up 'custom-tag "N-Up")
(custom-put-if-not 'ebnf-syntactic 'custom-version "20")
(custom-put-if-not 'ebnf-syntactic 'group-documentation "Syntactic customization.")
(custom-put-if-not 'ebnf-syntactic 'custom-tag "Syntactic")
(custom-put-if-not 'ps-print-printer 'custom-version "20")
(custom-put-if-not 'ps-print-printer 'group-documentation "Printer customization.")
(custom-put-if-not 'ps-print-printer 'custom-tag "Printer")
(custom-put-if-not 'rcirc 'custom-version "22.1")
(custom-put-if-not 'rcirc 'group-documentation "Simple IRC client.")
(custom-put-if-not 'url 'custom-version "22.1")
(custom-put-if-not 'url 'group-documentation "Uniform Resource Locator tool.")
(custom-put-if-not 'electric-help 'custom-version "21.1")
(custom-put-if-not 'electric-help 'group-documentation "Electric help facility.")
(custom-put-if-not 'align 'custom-version "21.1")
(custom-put-if-not 'align 'group-documentation "Align text to a specific column, by regexp.")
(custom-put-if-not 'tildify 'custom-version "21.1")
(custom-put-if-not 'tildify 'group-documentation "Adding missing hard spaces or other text fragments into texts.")
(custom-put-if-not 'inferior-lisp 'custom-version "22.1")
(custom-put-if-not 'inferior-lisp 'group-documentation "Run an outside Lisp in an Emacs buffer.")
(custom-put-if-not 'vc-bzr 'custom-version "22.2")
(custom-put-if-not 'vc-bzr 'group-documentation "VC bzr backend.")
(custom-put-if-not 'w32 'custom-version "22.1")
(custom-put-if-not 'w32 'group-documentation "MS-Windows specific features.")
(custom-put-if-not 'ansi-colors 'custom-version "21.1")
(custom-put-if-not 'ansi-colors 'group-documentation "Translating SGR control sequences to faces.
This translation effectively colorizes strings and regions based upon
SGR control sequences embedded in the text.  SGR (Select Graphic
Rendition) control sequences are defined in section 3.8.117 of the
ECMA-48 standard (identical to ISO/IEC 6429), which is freely available
as a PDF file <URL:http://www.ecma.ch/ecma1/STAND/ECMA-048.HTM>.")
(custom-put-if-not 'starttls 'custom-version "21.1")
(custom-put-if-not 'starttls 'group-documentation "Support for `Transport Layer Security' protocol.")
(custom-put-if-not 'midnight 'custom-version "20.3")
(custom-put-if-not 'midnight 'group-documentation "Run something every day at midnight.")
(custom-put-if-not 'filesets 'custom-version "22.1")
(custom-put-if-not 'filesets 'group-documentation "The fileset swapper.")
(custom-put-if-not 'ps-print 'custom-version "20")
(custom-put-if-not 'ps-print 'group-documentation "PostScript generator for Emacs.")
(custom-put-if-not 'cwarn 'custom-version "21.1")
(custom-put-if-not 'cwarn 'group-documentation "Highlight suspicious C and C++ constructions.")
(custom-put-if-not 'testcover 'custom-version "21.1")
(custom-put-if-not 'testcover 'group-documentation "Code-coverage tester.")
(custom-put-if-not 'ebnf-except 'custom-version "20")
(custom-put-if-not 'ebnf-except 'group-documentation "Except customization.")
(custom-put-if-not 'ebnf-except 'custom-tag "Except")
(custom-put-if-not 'ses 'custom-version "21.1")
(custom-put-if-not 'ses 'group-documentation "Simple Emacs Spreadsheet.")
(custom-put-if-not 'generic-x 'custom-version "20.3")
(custom-put-if-not 'generic-x 'group-documentation "A collection of generic modes.")
(custom-put-if-not 'gnus-delay 'custom-version "22.1")
(custom-put-if-not 'gnus-delay 'group-documentation "Arrange for sending postings later.")
(custom-put-if-not 'whitespace 'custom-version "21.1")
(custom-put-if-not 'whitespace 'group-documentation "Check for and fix five different types of whitespaces in source code.")
(custom-put-if-not 'gnus-audio 'custom-version "21.1")
(custom-put-if-not 'gnus-audio 'group-documentation "Playing sound in Gnus.")
(custom-put-if-not 'ps-print-color 'custom-version "20")
(custom-put-if-not 'ps-print-color 'group-documentation "Color customization.")
(custom-put-if-not 'ps-print-color 'custom-tag "Color")
(custom-put-if-not 'gnus-diary 'custom-version "22.1")
(custom-put-if-not 'gnus-diary 'group-documentation "Utilities on top of the nndiary back end for Gnus.")
(custom-put-if-not 'ebnf-optimization 'custom-version "20")
(custom-put-if-not 'ebnf-optimization 'group-documentation "Optimization customization.")
(custom-put-if-not 'ebnf-optimization 'custom-tag "Optimization")
(custom-put-if-not 'ps-print-horizontal 'custom-version "20")
(custom-put-if-not 'ps-print-horizontal 'group-documentation "Horizontal page layout.")
(custom-put-if-not 'ps-print-horizontal 'custom-tag "Horizontal")
(custom-put-if-not 'ps-print-face 'custom-version "20")
(custom-put-if-not 'ps-print-face 'group-documentation "Faces customization.")
(custom-put-if-not 'ps-print-face 'custom-tag "PS Faces")
(custom-put-if-not 'sha1 'custom-version "22.1")
(custom-put-if-not 'sha1 'group-documentation "Elisp interface for SHA1 hash computation.")
(custom-put-if-not 'vera 'custom-version "22.2")
(custom-put-if-not 'vera 'group-documentation "Customizations for Vera Mode.")
(custom-put-if-not 'net-utils 'custom-version "20.3")
(custom-put-if-not 'net-utils 'group-documentation "Network utility functions.")
(custom-put-if-not 'log-edit 'custom-version "21.1")
(custom-put-if-not 'log-edit 'group-documentation "Major mode for editing RCS and CVS commit messages.")
(custom-put-if-not 'pgg 'custom-version "22.1")
(custom-put-if-not 'pgg 'group-documentation "Glue for the various PGP implementations.")
(custom-put-if-not 'help-at-pt 'custom-version "22.1")
(custom-put-if-not 'help-at-pt 'group-documentation "Features for displaying local help.")
(custom-put-if-not 'ibuffer 'custom-version "22.1")
(custom-put-if-not 'ibuffer 'group-documentation "An advanced replacement for `buffer-menu'.

Ibuffer allows you to operate on buffers in a manner much like Dired.
Operations include sorting, marking by regular expression, and
the ability to filter the displayed buffers by various criteria.")
(custom-put-if-not 'gnus-charset 'custom-version "21.1")
(custom-put-if-not 'gnus-charset 'group-documentation "Group character set issues.")
(custom-put-if-not 'calculator 'custom-version "21.1")
(custom-put-if-not 'calculator 'group-documentation "Simple Emacs calculator.")
(custom-put-if-not 'conf 'custom-version "22.1")
(custom-put-if-not 'conf 'group-documentation "Configuration files.")
(custom-put-if-not 'ruler-mode 'custom-version "22.1")
(custom-put-if-not 'ruler-mode 'group-documentation "Display a ruler in the header line.")
(custom-put-if-not 'sieve 'custom-version "22.1")
(custom-put-if-not 'sieve 'group-documentation "Manage sieve scripts.")
(custom-put-if-not 'bs 'custom-version "21.1")
(custom-put-if-not 'bs 'group-documentation "Buffer Selection: Maintaining buffers by buffer menu.")
(custom-put-if-not 'cperl 'custom-version "20.3")
(custom-put-if-not 'cperl 'group-documentation "Major mode for editing Perl code.")
(custom-put-if-not 'pcl-cvs 'custom-version "21.1")
(custom-put-if-not 'pcl-cvs 'group-documentation "Special support for the CVS versioning system.")
(custom-put-if-not 'windmove 'custom-version "21.1")
(custom-put-if-not 'windmove 'group-documentation "Directional selection of windows in a frame.")
(custom-put-if-not 'ebnf-production 'custom-version "20")
(custom-put-if-not 'ebnf-production 'group-documentation "Production customization.")
(custom-put-if-not 'ebnf-production 'custom-tag "Production")
(custom-put-if-not 'checkdoc 'custom-version "20.3")
(custom-put-if-not 'checkdoc 'group-documentation "Support for doc string checking in Emacs Lisp.")
(custom-put-if-not 'verilog-mode 'custom-version "22.2")
(custom-put-if-not 'verilog-mode 'group-documentation "Facilitates easy editing of Verilog source text.")
(custom-put-if-not 'imap 'custom-version "21.1")
(custom-put-if-not 'imap 'group-documentation "Low-level IMAP issues.")
(custom-put-if-not 'ebnf-repeat 'custom-version "20")
(custom-put-if-not 'ebnf-repeat 'group-documentation "Repeat customization.")
(custom-put-if-not 'ebnf-repeat 'custom-tag "Repeat")
(custom-put-if-not 'ps-print-headers 'custom-version "20")
(custom-put-if-not 'ps-print-headers 'group-documentation "Headers & footers layout.")
(custom-put-if-not 'ps-print-headers 'custom-tag "Header & Footer")
(custom-put-if-not 'eudc 'custom-version "21.1")
(custom-put-if-not 'eudc 'group-documentation "Emacs Unified Directory Client.")
(custom-put-if-not 'kmacro 'custom-version "22.1")
(custom-put-if-not 'kmacro 'group-documentation "Simplified keyboard macro user interface.")
(custom-put-if-not 'socks 'custom-version "22.2")
(custom-put-if-not 'socks 'group-documentation "SOCKS Support")
(custom-put-if-not 'mac 'custom-version "22.1")
(custom-put-if-not 'mac 'group-documentation "Mac specific features.")
(custom-put-if-not 'gnus-registry 'custom-version "22.1")
(custom-put-if-not 'gnus-registry 'group-documentation "Article Registry.")
(custom-put-if-not 'tree-widget 'custom-version "22.1")
(custom-put-if-not 'tree-widget 'group-documentation "Customization support for the Tree Widget library.")
(custom-put-if-not 'table 'custom-version "22.1")
(custom-put-if-not 'table 'group-documentation "Text based table manipulation utilities.
See `table-insert' for examples about how to use.")
(custom-put-if-not 'table 'custom-tag "Table")
(custom-put-if-not 'recentf 'custom-version "21.1")
(custom-put-if-not 'recentf 'group-documentation "Maintain a menu of recently opened files.")
(custom-put-if-not 'fortune 'custom-version "21.1")
(custom-put-if-not 'fortune 'group-documentation "Settings for fortune.")
(custom-put-if-not 'diff-mode 'custom-version "21.1")
(custom-put-if-not 'diff-mode 'group-documentation "Major mode for viewing/editing diffs.")
(custom-put-if-not 'ps-print-font 'custom-version "20")
(custom-put-if-not 'ps-print-font 'group-documentation "Fonts customization.")
(custom-put-if-not 'ps-print-font 'custom-tag "Font")
(custom-put-if-not 'todo 'custom-version "21.1")
(custom-put-if-not 'todo 'group-documentation "Maintain a list of todo items.")
(custom-put-if-not 'ebnf-special 'custom-version "20")
(custom-put-if-not 'ebnf-special 'group-documentation "Special customization.")
(custom-put-if-not 'ebnf-special 'custom-tag "Special")
(custom-put-if-not 'ido 'custom-version "22.1")
(custom-put-if-not 'ido 'group-documentation "Switch between files using substrings.")
(custom-put-if-not 'gnus-outlook-deuglify 'custom-version "22.1")
(custom-put-if-not 'gnus-outlook-deuglify 'group-documentation "Deuglify articles generated by broken user agents like MS Outlook (Express).")
(custom-put-if-not 'quickurl 'custom-version "21.1")
(custom-put-if-not 'quickurl 'group-documentation "Insert an URL based on text at point in buffer.")
(custom-put-if-not 'comment 'custom-version "21.1")
(custom-put-if-not 'comment 'group-documentation "Indenting and filling of comments.")
(custom-put-if-not 'gametree 'custom-version "20.3")
(custom-put-if-not 'gametree 'group-documentation "Manage game analysis trees in Emacs.")
(custom-put-if-not 'gmm 'custom-version "22.1")
(custom-put-if-not 'gmm 'group-documentation "Utility functions for Gnus, Message and MML")
(custom-put-if-not 'ps-print-zebra 'custom-version "20")
(custom-put-if-not 'ps-print-zebra 'group-documentation "Zebra customization.")
(custom-put-if-not 'ps-print-zebra 'custom-tag "Zebra")
(custom-put-if-not 'mailcap 'custom-version "21.1")
(custom-put-if-not 'mailcap 'group-documentation "Definition of viewers for MIME types.")
(custom-put-if-not 'printing 'custom-version "22.1")
(custom-put-if-not 'printing 'group-documentation "Printing Utilities group.")
(custom-put-if-not 'printing 'custom-tag "Printing Utilities")
(custom-put-if-not 'ls-lisp 'custom-version "21.1")
(custom-put-if-not 'ls-lisp 'group-documentation "Emulate the ls program completely in Emacs Lisp.")
(custom-put-if-not 'glasses 'custom-version "21.1")
(custom-put-if-not 'glasses 'group-documentation "Make unreadable code likeThis(one) readable.")
(custom-put-if-not 'ebnf2ps 'custom-version "20")
(custom-put-if-not 'ebnf2ps 'group-documentation "Translate an EBNF to a syntactic chart on PostScript.")
(custom-put-if-not 'thumbs 'custom-version "22.1")
(custom-put-if-not 'thumbs 'group-documentation "Thumbnails previewer.")
(custom-put-if-not 'delphi 'custom-version "21.1")
(custom-put-if-not 'delphi 'group-documentation "Major mode for editing Delphi source in Emacs.")

(defvar custom-versions-load-alist '(("21.2" mm-util) ("20.3.3" "dos-vars") ("20.1" time-stamp) ("21.3" sql gnus-agent ange-ftp) ("19.29" time-stamp) ("22" ebnf2ps) ("22.2" vc-hg bibtex-style vc-mtn gnus-sum css-mode desktop tls mail-source find-dired gdb-ui dired) ("20.3" easymenu dabbrev ffap xscheme rmail paren mailabbrev uce which-func diary-lib sendmail debug msb avoid hexl vcursor vc compile etags browse-url add-log find-func cus-edit) ("21.1" server debug rmailedit ezimage dabbrev latin1-disp gnus-start hideshow strokes sgml-mode net-utils cperl-mode ange-ftp gnus-nocem paren fortran solar etags rmail sb-image vc-sccs vc gnus-group gnus-sum smtpmail add-log sendmail find-func wid-edit vc-rcs gnus-art nnmail message ps-print vc-cvs cus-edit gnus-agent flyspell rmailsum browse-url) ("20.4" crisp sh-script compile hilit-chg) ("20" ps-print ebnf2ps) ("20.8" sql) ("22.1" imenu mm-view cal-tex gnus-srvr gnus-score smiley add-log bookmark footnote shadowfile gnus-int view hi-lock gnus-win server tcl descr-text latin1-disp fortran landmark gnus-delay tex-mode sgml-mode gnus-group sql gnus-util mail-extr sh-script hl-line make-mode mml2015 vc-cvs ielm nnimap generic-x imap gnus-soup gnus-start mml-sec comint vc-mcvs desktop locate gnus-msg compare-w info uudecode gnus-agent cal-dst spam find-dired diff-mode ange-ftp mml gnus-fun ispell gnus-spec gnus warnings smtpmail sendmail appt dabbrev pop3 smime time binhex dired rmail allout mm-url gdb-ui vc-svn mm-decode mm-util vc pgg-def mm-uu autorevert mail-source flow-fill diary-lib iswitchb gnus-art find-func gnus-cite tls nnmail glasses deuglify calendar ffap compile starttls cus-edit gnus-sum grep keypad message))
 "For internal use by custom.")

(provide 'cus-load)

;; Local Variables:
;; version-control: never
;; no-byte-compile: t
;; no-update-autoloads: t
;; End:
;;; cus-load.el ends here
